==> jetspeed-japan-1.4b4_ja_1-src.zip: jetspeed-japan-1.4b4_ja_1-src/src/java/org/apache/jetspeed/services/customlocalization/CustomLocalizationTool.java <==
/* ====================================================================
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 2000-2003 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Apache" and "Apache Software Foundation" and
 *     "Apache Jetspeed" must not be used to endorse or promote products
 *    derived from this software without prior written permission. For
 *    written permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache" or
 *    "Apache Jetspeed", nor may "Apache" appear in their name, without
 *    prior written permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */
package org.apache.jetspeed.services.customlocalization;

import java.util.Locale;
import java.util.ResourceBundle;
import java.util.MissingResourceException;
import org.apache.turbine.services.pull.ApplicationTool;
import org.apache.turbine.util.Log;
import org.apache.turbine.util.RunData;



/**
 * Custom localization tool.
 *
 * @author <a href="mailto:desmax74@yahoo.it">Dess Massimiliano</a>
 * @author <a href="mailto:massimiliano.dessi@gruppoatlantis.it">Dess Massimiliano</a>
 * @author <a href="mailto:massimiliano.dessi@gruppoatlantis.com">Dess Massimiliano</a>
 * @version $Id: CustomLocalizationTool.java.patch,v 1.1 2003/06/06 16:32:06 shinsuke Exp $
 */
public class CustomLocalizationTool implements ApplicationTool
{

    public CustomLocalizationTool()
    {
        refresh();
    }

    public String get(String key)
    {
        try
        {
            String s = CustomLocalization.getString(getBundleName(null), getLocale(), key);
            return s;
        }
        catch (MissingResourceException noKey)
        {
            Log.error(noKey);
        }
        return null;
    }

    /**
     * Gets localized key from the default bundle and the provided locale.
     * Returns <code>null</code> if the resource is missing.
     *
     * @param key string to translate.
     * @param locale prefered locale for translation.
     * @return localized key.
     */
    public String get(String key, Locale locale)
    {
        if (locale == null)
        {
            locale = getLocale();
        }

        String s = null;
        try
        {
            s = CustomLocalization.getString(getBundleName(null), locale, key);
        }
        catch (MissingResourceException noKey)
        {
            Log.error(noKey);
        }

        return s;
    }


    public Locale getLocale()
    {
        return locale;
    }

    protected String getBundleName(Object data)
    {
        return CustomLocalization.getDefaultBundleName();
    }

    public final void init(Object data)
    {
        if (data instanceof RunData)
        {
            locale = CustomLocalization.getLocale((RunData)data);
            bundleName = getBundleName(data);
        }
    }

    public void refresh()
    {
        locale = null;
        bundle = null;
        bundleName = null;
    }

    protected Locale locale;
    private ResourceBundle bundle;
    private String bundleName;
    boolean debug;
}

==> jetspeed-japan-1.5_dev_ja_1-src.zip: jetspeed-japan-1.5_dev_ja_1-src/src/java/org/apache/jetspeed/services/customlocalization/CustomLocalizationTool.java <==
/* ====================================================================
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 2000-2003 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Apache" and "Apache Software Foundation" and
 *    "Apache Jetspeed" must not be used to endorse or promote products
 *    derived from this software without prior written permission. For
 *    written permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    "Apache Jetspeed", nor may "Apache" appear in their name, without
 *    prior written permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */
package org.apache.jetspeed.services.customlocalization;

import java.util.Locale;
import java.util.ResourceBundle;
import java.util.MissingResourceException;

import org.apache.jetspeed.services.logging.JetspeedLogFactoryService;
import org.apache.jetspeed.services.logging.JetspeedLogger;

import org.apache.turbine.services.pull.ApplicationTool;
import org.apache.turbine.util.RunData;



/**
 * Custom localization tool.
 *
 * @author <a href="mailto:desmax74@yahoo.it">Dess Massimiliano</a>
 * @author <a href="mailto:massimiliano.dessi@gruppoatlantis.it">Dess Massimiliano</a>
 * @author <a href="mailto:massimiliano.dessi@gruppoatlantis.com">Dess Massimiliano</a>
 * @version $Id: CustomLocalizationTool.java,v 1.4 2004/02/03 04:26:16 taylor Exp $
 */
public class CustomLocalizationTool implements ApplicationTool
{
    /**
     * Static initialization of the logger for this class
     */    
    private static final JetspeedLogger logger = JetspeedLogFactoryService.getLogger(CustomLocalizationTool.class.getName());    
    
    public CustomLocalizationTool()
    {
        refresh();
    }

    public String get(String key)
    {
        try
        {
            String s = CustomLocalization.getString(getBundleName(null), getLocale(), key);
            return s;
        }
        catch (MissingResourceException noKey)
        {
            logger.error("Exception", noKey);
        }
        return null;
    }

    /**
     * Gets localized key from the default bundle and the provided locale.
     * Returns <code>null</code> if the resource is missing.
     *
     * @param key string to translate.
     * @param locale prefered locale for translation.
     * @return localized key.
     */
    public String get(String key, Locale locale)
    {
        if (locale == null)
        {
            locale = getLocale();
        }

        String s = null;
        try
        {
            s = CustomLocalization.getString(getBundleName(null), locale, key);
        }
        catch (MissingResourceException noKey)
        {
            logger.error("Exception", noKey);
        }

        return s;
    }


    public Locale getLocale()
    {
        return locale;
    }

    protected String getBundleName(Object data)
    {
        return CustomLocalization.getDefaultBundleName();
    }

    public final void init(Object data)
    {
        if (data instanceof RunData)
        {
            locale = CustomLocalization.getLocale((RunData)data);
            bundleName = getBundleName(data);
        }
    }

    public void refresh()
    {
        locale = null;
        bundle = null;
        bundleName = null;
    }

    protected Locale locale;
    private ResourceBundle bundle;
    private String bundleName;
    boolean debug;
}
